.. _module_hydra_core_elogger:

logger
======

This sections contains module documentation of logger module.

logger
^^^^^^

Module provides class Logger.
Unit tests available at hydratk/core/logger/01_methods_ut.jedi

**Attributes** :

* _emulate_print - print line break

**Methods** :

* spout

Method prints message including line break if enabled.